hotspot/src/share/vm/gc/shared/genCollectedHeap.hpp
changeset 33212 906b3d079b13
parent 32735 c6063d028c3c
child 33580 c2d95df2c54e
--- a/hotspot/src/share/vm/gc/shared/genCollectedHeap.hpp	Thu Oct 15 00:42:15 2015 +0000
+++ b/hotspot/src/share/vm/gc/shared/genCollectedHeap.hpp	Wed Oct 14 09:33:45 2015 +0200
@@ -64,8 +64,8 @@
   Generation* _young_gen;
   Generation* _old_gen;
 
-  // The singleton Gen Remembered Set.
-  GenRemSet* _rem_set;
+  // The singleton CardTable Remembered Set.
+  CardTableRS* _rem_set;
 
   // The generational collector policy.
   GenCollectorPolicy* _gen_policy;
@@ -361,9 +361,9 @@
   // collection.
   virtual bool is_maximal_no_gc() const;
 
   // This function returns the "GenRemSet" object that allows us to scan
   // generations in a fully generational heap.
-  GenRemSet* rem_set() { return _rem_set; }
+  CardTableRS* rem_set() { return _rem_set; }
 
   // Convenience function to be used in situations where the heap type can be
   // asserted to be this type.
@@ -361,9 +361,9 @@
   virtual bool is_maximal_no_gc() const;
 
-  // This function returns the "GenRemSet" object that allows us to scan
+  // This function returns the CardTableRS object that allows us to scan
   // generations in a fully generational heap.